package com.yihu.hos.server.service;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.yihu.ehr.dbhelper.common.DBList;
import com.yihu.ehr.dbhelper.common.MongodbQuery;
import com.yihu.ehr.dbhelper.common.QueryCondition;
import com.yihu.ehr.dbhelper.common.QueryEntity;
import com.yihu.hos.common.SigarUtil;
import com.yihu.hos.crawler.model.transform.EhrCondition;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import org.hyperic.sigar.SigarException;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 服务器指标 业务类
 *
 * @author HZY
 * @vsrsion 1.0
 * Created at 2016/10/14.
 */
@Component
public class ServerMetricsService {

    /**
     * 获取历史服务器监控指标
     *
     * @param type  监控类型（cpu，内存等）
     * @param begin 开始时间
     * @param end   结束时间
     * @return
     */
    public JSONArray getHistory(String type, String begin, String end) throws Exception {
        ObjectMapper objectMapper = new ObjectMapper();
        JSONArray result = new JSONArray();
        List<EhrCondition> queryParams = new ArrayList<>();
        queryParams.add(new EhrCondition(" > ", "create_date", begin));
        queryParams.add(new EhrCondition(" < ", "create_date", end));
        result = collectionData(type, objectMapper.writeValueAsString(queryParams));
        return result;
    }

    /**
     * mongodb 查询方法
     *
     * @param tableCode
     * @param condition
     * @return
     * @throws Exception
     */
    public JSONArray collectionData(String tableCode, String condition) throws Exception {
        JSONArray result = new JSONArray();
        try {
            MongodbQuery mdb = new MongodbQuery("envHealth");//TODO 提取到配置文件中
            QueryEntity qe = new QueryEntity(tableCode);
            //设置参数
            if (!StringUtils.isEmpty(condition) && !"{}".equals(condition)) {
                JSONArray ar = JSONArray.fromObject(condition);
                for (int i = 0; i < ar.size(); i++) {
                    JSONObject jo = (JSONObject) ar.get(i);
                    String andOr = String.valueOf(jo.get("andOr"));
                    String field = String.valueOf(jo.get("field"));
                    String cond = String.valueOf(jo.get("condition"));
                    String value = String.valueOf(jo.get("value"));
                    qe.addCondition(new QueryCondition(andOr, cond, field, value));
                }
            }
            DBList list = mdb.query(qe);
            result = JSONArray.fromObject(list.getList().toString());
        } catch (Exception e) {
            e.printStackTrace();
        }
        return result;
    }

    /**
     * 获取当前 服务器监控指标
     * @param type
     * @return
     * @throws SigarException
     */
    public JSONObject getCurrent(String type) throws SigarException {
        JSONObject result = new JSONObject();
        switch (type) {
            case "cpu" : // cpu
                result = JSONObject.fromObject(SigarUtil.cpu());
                break;
            case "memory" : // 内存
                result = JSONObject.fromObject(SigarUtil.memory());
                break;
            case "files" : // 硬盘
                result = JSONObject.fromObject(SigarUtil.file());
                break;
            case "net" :// 网络
                result = JSONObject.fromObject(SigarUtil.net());
                break;
        }
        return result;
    }



}
